@@ -184,7 +184,9 @@ class Database(object):
         if name not in self.collection_names():
             return
 
-        self[name].drop_indexes() # must manually drop indexes
+        # TODO must manually drop indexes for now, but this is a bug that will
+        # be fixed on the database side at some point
+        self[name].drop_indexes()
 
         self._command({"drop": unicode(name)})
 
